@@ -1,13 +1,15 @@
 "are.parcau.valid" <-
 function(para,nowarn=FALSE) {
     if(! is.cau(para)) return(FALSE)
+    if(any(is.na(para$para))) return(FALSE)
+
     U <- para$para[1] 
     A <- para$para[2] 
     op <- options()
     GO <- TRUE
     if(nowarn == TRUE) options(warn=-1)
     if(A <= 0) {
-      warning("Parameters are invalid")
+      warning("Parameter A is not > 0, invalid")
       GO <- FALSE
     }
     options(op)
