@@ -5,11 +5,13 @@ function(x, para) {
     B <- 1/para$para[1]
     K <-   para$para[2]
     H <-   para$para[3]
+
     x[x < 0] <- NA
     e1 <- 1 - exp(-H + H*exp(-B*x))
     e2 <- 1 - exp(-H)
-    Fx <- (e1/e2)^K
-    return(Fx)
+    f  <- (e1/e2)^K
+    names(f) <- NULL
+    return(f)
 }
 
 
