@@ -1,5 +1,5 @@
 "fliplmoms" <-
-function(lmom, checklmom=TRUE) {
+function(lmom, flip=NULL, checklmom=TRUE) {
     if(length(lmom$lambdas) == 0) {
     	warning("need vectorized L-moments, see lmorph()?");
     	return();
@@ -9,8 +9,12 @@ function(lmom, checklmom=TRUE) {
       return();
     }
     if(length(lmom$flip) == 0) {
-      warning("The flip is not provided in the lmom list");
-      return();
+      if(is.null(flip)) {
+        warning("The flip is not provided in the lmom list or as argument");
+        return();
+      } else {
+        lmom$flip <- flip
+      }
     }
    odd <- seq(3,length(lmom$lambda), by=2);
    lmom$lambdas[odd] <- -1*lmom$lambdas[odd];
@@ -19,4 +23,3 @@ function(lmom, checklmom=TRUE) {
    lmom$ratios[2]    <- lmom$lambda[2]/lmom$lambdas[1];
    return(lmom);
 }
-
