@@ -9,17 +9,16 @@ function(f, para, paracheck=TRUE) {
    A <- para$para[2]
    N <- para$para[3]
 
-   SMALL.NU <- 1.000001 # arrived from manual experiments
-   LARGE.NU <- 1000     # limits of experiments yielding the polynomial
+   SMALL.NU <- 1.001  # arrived from manual experiments involving theoLmoms() testing
+   LARGE.NU <- 10^5.5 # arrived from manual experiments involving theoLmoms() testing
+
    if(N < SMALL.NU) N <- SMALL.NU
    if(N > LARGE.NU) N <- LARGE.NU
 
-   if(N == LARGE.NU) {
-      return(qnorm(f, mean=U, sd=A))
-   } else {
-      x <- U + A*qt(f, N)
-      names(x) <- NULL
-      return(x)
-   }
+   x <- U + A*qt(f, N)
+   names(x) <- NULL
+   return(x)
+
    stop("Should not be here in execution")
 }
+
