@@ -1,7 +1,9 @@
 "quawei" <-
-function(f,para) { 
+function(f,para,paracheck=TRUE) { 
     if(! check.fs(f)) return()
-    if(! are.parwei.valid(para)) return()
+    if(paracheck == TRUE) {
+      if(! are.parwei.valid(para)) return()
+    }
     ZETA <- para$para[1]
     B    <- para$para[2]
     D    <- para$para[3]
@@ -10,5 +12,5 @@ function(f,para) {
     A  <- B/D
     XI <- ZETA - B 
     gev.para <- list(type = 'gev', para = c(XI,A,K))
-    return(-quagev(1-f,gev.para))
+    return(-quagev(1-f,gev.para,paracheck=paracheck))
 }
